Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(467)

Unified Diff: runtime/include/dart_api.h

Issue 1143783003: Add the streamListen and streamCancel rpcs to the vm service. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: before commit Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/vmservice/server.dart ('k') | runtime/observatory/lib/service_common.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_api.h
diff --git a/runtime/include/dart_api.h b/runtime/include/dart_api.h
index 7094b4be438cf137201308a8bb68600ad593f5d3..401a445eb341cebf3a986b32fcdbca136241ab7d 100755
--- a/runtime/include/dart_api.h
+++ b/runtime/include/dart_api.h
@@ -2817,35 +2817,36 @@ typedef const char* (*Dart_ServiceRequestCallback)(
void* user_data);
/**
- * Register a Dart_ServiceRequestCallback to be called to handle requests
- * with name on a specific isolate. The callback will be invoked with the
- * current isolate set to the request target.
+ * Register a Dart_ServiceRequestCallback to be called to handle
+ * requests for the named rpc on a specific isolate. The callback will
+ * be invoked with the current isolate set to the request target.
*
* \param name The name of the command that this callback is responsible for.
* \param callback The callback to invoke.
* \param user_data The user data passed to the callback.
*
- * NOTE: If multiple callbacks with the same name are registered, only the
- * last callback registered will be remembered.
+ * NOTE: If multiple callbacks with the same name are registered, only
+ * the last callback registered will be remembered.
*/
DART_EXPORT void Dart_RegisterIsolateServiceRequestCallback(
- const char* name,
+ const char* method,
Dart_ServiceRequestCallback callback,
void* user_data);
/**
- * Register a Dart_ServiceRequestCallback to be called to handle requests
- * with name. The callback will be invoked without a current isolate.
+ * Register a Dart_ServiceRequestCallback to be called to handle
+ * requests for the named rpc. The callback will be invoked without a
+ * current isolate.
*
* \param name The name of the command that this callback is responsible for.
* \param callback The callback to invoke.
* \param user_data The user data passed to the callback.
*
- * NOTE: If multiple callbacks with the same name are registered, only the
- * last callback registered will be remembered.
+ * NOTE: If multiple callbacks with the same name are registered, only
+ * the last callback registered will be remembered.
*/
DART_EXPORT void Dart_RegisterRootServiceRequestCallback(
- const char* name,
+ const char* method,
Dart_ServiceRequestCallback callback,
void* user_data);
« no previous file with comments | « runtime/bin/vmservice/server.dart ('k') | runtime/observatory/lib/service_common.dart » ('j') | no next file with comments »
@@ -2817,35 +2817,36 @@ typedef const char* (*Dart_ServiceRequestCallback)(
*
- * \param name The name of the command that this callback is responsible for.
+ * \param method The name of the method that this callback is responsible for.
* \param callback The callback to invoke.
* \param user_data The user data passed to the callback.
@@ -2817,35 +2817,36 @@ typedef const char* (*Dart_ServiceRequestCallback)(
*
- * \param name The name of the command that this callback is responsible for.
+ * \param method The name of the command that this callback is responsible for.
* \param callback The callback to invoke.
* \param user_data The user data passed to the callback.

Powered by Google App Engine
This is Rietveld 408576698